@@ -2,11 +2,13 @@ from .feedback import FeedbackForm
 from .question import QuestionsForm
 from .resource import ResourceForm
 from .submission import InfoForm, SubmissionFilterForm
+from .tag import TagForm
 
 __all__ = [
-    'FeedbackForm',
-    'InfoForm',
-    'QuestionsForm',
-    'ResourceForm',
-    'SubmissionFilterForm',
+    "FeedbackForm",
+    "InfoForm",
+    "QuestionsForm",
+    "ResourceForm",
+    "SubmissionFilterForm",
+    "TagForm",
 ]
