@@ -21,6 +21,13 @@ class ReviewScoreCategory(models.Model):
         blank=True,
         help_text=_("Leave empty to use this category for all tracks."),
     )
+    is_independent = models.BooleanField(
+        default=False,
+        verbose_name=_("Independent score"),
+        help_text=_(
+            "Independent scores are not part of the total score. Instead they are shown in a separate column in the review dashboard."
+        ),
+    )
 
     objects = ScopedManager(event="event")
 
@@ -33,6 +40,11 @@ class ReviewScoreCategory(models.Model):
         for review in event.reviews.all():
             review.save(update_score=True)
 
+    def save(self, *args, **kwargs):
+        if self.is_independent:
+            self.weight = 0
+        return super().save(*args, **kwargs)
+
 
 class ReviewScore(models.Model):
     category = models.ForeignKey(
@@ -47,7 +59,7 @@ class ReviewScore(models.Model):
         value = self.value
         if int(value) == value:
             value = int(value)
-        if self.label:
+        if self.label and self.label != str(value):
             return f"{self.label} ({value})"
         return str(value)
 
@@ -147,14 +159,10 @@ class Review(models.Model):
         return str(self.score)
 
     def update_score(self):
-        track = self.submission.track
-        track_filter = models.Q(category__limit_tracks__isnull=True)
-        if track:
-            track_filter |= models.Q(category__limit_tracks__in=[track])
         scores = (
             self.scores.all()
             .select_related("category")
-            .filter(track_filter, category__active=True)
+            .filter(category__in=self.submission.score_categories)
         )
         self.score = self.calculate_score(scores)
 
